@@ -1,5 +1,7 @@
 #include <RcppEigen.h>
+#ifdef _OPENMP
 #include <omp.h>
+#endif
 #include "Omnibus_Pieces.h"
 #include "Calc_Repeated.h"
 #include "Colossus_types.h"
@@ -28,10 +30,13 @@ using Rcpp::as;
 
 
 //' Utility function to refresh risk and subterm matrices for Cox Omnibus function
+//'
 //' \code{Cox_Refresh_R_TERM} Called to update matrices
 //' @inheritParams CPP_template
 //'
 //' @return Updates matrices in place
+//' @noRd
+//'
 // [[Rcpp::export]]
 void Cox_Refresh_R_TERM(const int& totalnum, const int& reqrdnum, const int& term_tot, double& dint, double& dslp,double& dose_abs_max, double& abs_max, const MatrixXd& df0, MatrixXd& T0, MatrixXd& Td0, MatrixXd& Tdd0, MatrixXd& Te, MatrixXd& R, MatrixXd& Rd, MatrixXd& Rdd, MatrixXd& Dose, MatrixXd& nonDose,  MatrixXd& TTerm,  MatrixXd& nonDose_LIN, MatrixXd& nonDose_PLIN, MatrixXd& nonDose_LOGLIN, MatrixXd& RdR, MatrixXd& RddR, bool basic_bool, bool single_bool){
     T0 = MatrixXd::Zero(df0.rows(), totalnum); //preallocates matrix for Term column
@@ -41,6 +46,7 @@ void Cox_Refresh_R_TERM(const int& totalnum, const int& reqrdnum, const int& ter
 		Rd = MatrixXd::Zero(df0.rows(), reqrdnum); //preallocates matrix for Risk derivatives
 		Rdd = MatrixXd::Zero(df0.rows(), reqrdnum*(reqrdnum+1)/2); //preallocates matrix for Risk second derivatives
         RdR = MatrixXd::Zero(df0.rows(), reqrdnum); //preallocates matrix for Risk to derivative ratios
+        TTerm = MatrixXd::Zero(df0.rows(),1); //matrix of term values
     } else if (single_bool){
 		//
 		Te = MatrixXd::Zero(df0.rows(), 1); //preallocates matrix for column terms used for temporary storage
@@ -76,10 +82,13 @@ void Cox_Refresh_R_TERM(const int& totalnum, const int& reqrdnum, const int& ter
 }
 
 //' Utility function to refresh side matrices for Cox Omnibus
+//'
 //' \code{Cox_Refresh_R_SIDES} Called to fresh repeated sum calculation matrices
 //' @inheritParams CPP_template
 //'
 //' @return Updates matrices in place: risk storage matrices
+//' @noRd
+//'
 // [[Rcpp::export]]
 void Cox_Refresh_R_SIDES( const int& reqrdnum, const int& ntime, MatrixXd& Rls1, MatrixXd& Rls2, MatrixXd& Rls3, MatrixXd& Lls1, MatrixXd& Lls2, MatrixXd& Lls3, NumericVector& STRATA_vals, bool strata_bool, bool single_bool){
     if (strata_bool){
@@ -107,16 +116,15 @@ void Cox_Refresh_R_SIDES( const int& reqrdnum, const int& ntime, MatrixXd& Rls1,
 
 
 //' Utility function to perform calculation of terms and risks for Cox Omnibus
+//'
 //' \code{Cox_Term_Risk_Calc} Called to perform repeated term and risk calculations
 //' @inheritParams CPP_template
 //'
 //' @return Updates matrices in place: risk storage matrices
+//' @noRd
+//'
 // [[Rcpp::export]]
 void Cox_Term_Risk_Calc(string modelform, const StringVector& tform, const IntegerVector& Term_n, const int& totalnum, const int& fir, const IntegerVector& dfc, int term_tot, MatrixXd& T0, MatrixXd& Td0, MatrixXd& Tdd0, MatrixXd& Te, MatrixXd& R, MatrixXd& Rd, MatrixXd& Rdd, MatrixXd& Dose, MatrixXd& nonDose, VectorXd beta_0,const  MatrixXd& df0,const double& dint, const double& dslp,  MatrixXd& TTerm,  MatrixXd& nonDose_LIN, MatrixXd& nonDose_PLIN, MatrixXd& nonDose_LOGLIN, MatrixXd& RdR, MatrixXd& RddR, const int& nthreads, bool debugging, const IntegerVector& KeepConstant, bool verbose, bool basic_bool, bool single_bool, int start, const double gmix_theta, const IntegerVector& gmix_term){
-    time_point<system_clock> end_point;
-    end_point = system_clock::now();
-    auto ending = time_point_cast<microseconds>(end_point).time_since_epoch().count(); //The time duration is tracked
-    auto gibtime = system_clock::to_time_t(system_clock::now());
     int reqrdnum = totalnum - sum(KeepConstant);
     if (basic_bool){
 		// Calculates the subterm and term values
@@ -138,15 +146,6 @@ void Cox_Term_Risk_Calc(string modelform, const StringVector& tform, const Integ
 			Rcout << " " << endl;
 		}
 		//
-		//
-		//if (verbose){
-		//	end_point = system_clock::now();
-		//	ending = time_point_cast<microseconds>(end_point).time_since_epoch().count();
-		//	Rcout << "C++ Note: df99," << (ending-start) << ",Prep_Terms" <<endl;
-		//	gibtime = system_clock::to_time_t(system_clock::now());
-		//	Rcout << "C++ Note: Current Time, " << ctime(&gibtime) << endl;
-		//}
-		//
 		// Calculates the risk for each row
 		Make_Risks_Basic(totalnum, T0, R, Rd, Rdd, RdR, nthreads, debugging,df0,dfc,KeepConstant);
 		//
@@ -173,11 +172,6 @@ void Cox_Term_Risk_Calc(string modelform, const StringVector& tform, const Integ
 			}
 			Rcout << " " << endl;
 			//
-			//end_point = system_clock::now();
-			//ending = time_point_cast<microseconds>(end_point).time_since_epoch().count();
-			//Rcout << "C++ Note: df100 " << (ending-start) << " " <<0<< " " <<0<< " " <<-1<< ",Prep_R" <<endl;
-			//gibtime = system_clock::to_time_t(system_clock::now());
-			//Rcout << "C++ Note: Current Time, " << ctime(&gibtime) << endl;
 		}
 	} else if (single_bool){
 		// Calculates the subterm and term values
@@ -225,14 +219,6 @@ void Cox_Term_Risk_Calc(string modelform, const StringVector& tform, const Integ
 		}
 		//
 		//
-		//if (verbose){
-		//	end_point = system_clock::now();
-		//	ending = time_point_cast<microseconds>(end_point).time_since_epoch().count();
-		//	Rcout << "C++ Note: df99," << (ending-start) << ",Prep_Terms" <<endl;
-		//	gibtime = system_clock::to_time_t(system_clock::now());
-		//	Rcout << "C++ Note: Current Time, " << ctime(&gibtime) << endl;
-		//}
-		//
 		// Calculates the risk for each row
         Make_Risks_Single(modelform, tform, Term_n, totalnum, fir, T0, Te, R, Dose, nonDose, TTerm, nonDose_LIN, nonDose_PLIN, nonDose_LOGLIN, nthreads, debugging,KeepConstant,gmix_theta, gmix_term);
 		//
@@ -247,12 +233,6 @@ void Cox_Term_Risk_Calc(string modelform, const StringVector& tform, const Integ
 				Rcout << R.col(0).sum() << " ";
 			}
 			Rcout << " " << endl;
-			//
-			//end_point = system_clock::now();
-			//ending = time_point_cast<microseconds>(end_point).time_since_epoch().count();
-			//Rcout << "C++ Note: df100 " << (ending-start) << " " <<0<< " " <<0<< " " <<-1<< ",Prep_R" <<endl;
-			//gibtime = system_clock::to_time_t(system_clock::now());
-			//Rcout << "C++ Note: Current Time, " << ctime(&gibtime) << endl;
 		}
 	} else {
 		//
@@ -313,14 +293,6 @@ void Cox_Term_Risk_Calc(string modelform, const StringVector& tform, const Integ
 		}
 		//
 		//
-		//if (verbose){
-		//	end_point = system_clock::now();
-		//	ending = time_point_cast<microseconds>(end_point).time_since_epoch().count();
-		//	Rcout << "C++ Note: df99," << (ending-start) << ",Prep_Terms" <<endl;
-		//	gibtime = system_clock::to_time_t(system_clock::now());
-		//	Rcout << "C++ Note: Current Time, " << ctime(&gibtime) << endl;
-		//}
-		//
 		// Calculates the risk for each row
         Make_Risks(modelform, tform, Term_n, totalnum, fir, T0, Td0, Tdd0, Te, R, Rd, Rdd, Dose, nonDose, TTerm, nonDose_LIN, nonDose_PLIN, nonDose_LOGLIN, RdR, RddR, nthreads, debugging,KeepConstant,gmix_theta, gmix_term);
 		//
@@ -348,27 +320,21 @@ void Cox_Term_Risk_Calc(string modelform, const StringVector& tform, const Integ
 			}
 			Rcout << " " << endl;
 			//
-			//end_point = system_clock::now();
-			//ending = time_point_cast<microseconds>(end_point).time_since_epoch().count();
-			//Rcout << "C++ Note: df100 " << (ending-start) << " " <<0<< " " <<0<< " " <<-1<< ",Prep_R" <<endl;
-			//gibtime = system_clock::to_time_t(system_clock::now());
-			//Rcout << "C++ Note: Current Time, " << ctime(&gibtime) << endl;
 		}
 	}
 	return;
 }
 
 //' Utility function to perform calculation of Repeated Calculations and Log-Likelihood for Cox Omnibus
+//'
 //' \code{Cox_Side_LL_Calc} Called to perform repeated term and risk calculations
 //' @inheritParams CPP_template
 //'
 //' @return Updates matrices in place: risk storage matrices
+//' @noRd
+//'
 // [[Rcpp::export]]
 void Cox_Side_LL_Calc(const int& reqrdnum, const int& ntime, const IntegerMatrix& RiskFail, const StringMatrix&  RiskGroup_Strata, const vector<string>& RiskGroup, const int& totalnum, const int& fir, MatrixXd& R, MatrixXd& Rd, MatrixXd& Rdd,  MatrixXd& Rls1, MatrixXd& Rls2, MatrixXd& Rls3, MatrixXd& Lls1, MatrixXd& Lls2, MatrixXd& Lls3, const VectorXd& cens_weight, NumericVector& STRATA_vals, VectorXd beta_0 , MatrixXd& RdR, MatrixXd& RddR, vector<double>& Ll, vector<double>& Lld, vector<double>& Lldd, const int& nthreads, bool debugging, const IntegerVector& KeepConstant,string ties_method, bool verbose,bool strata_bool, bool CR_bool, bool basic_bool, bool single_bool, int start, int iter_stop){
-    time_point<system_clock> end_point;
-    end_point = system_clock::now();
-    auto ending = time_point_cast<microseconds>(end_point).time_since_epoch().count(); //The time duration is tracked
-    auto gibtime = system_clock::to_time_t(system_clock::now());
     // Calculates the side sum terms used
     if (strata_bool){
         if (CR_bool){
@@ -395,14 +361,6 @@ void Cox_Side_LL_Calc(const int& reqrdnum, const int& ntime, const IntegerMatrix
         Calculate_Sides( RiskFail, RiskGroup, totalnum, ntime, R, Rd, Rdd, Rls1, Rls2, Rls3, Lls1, Lls2, Lls3,nthreads, debugging,KeepConstant);
     }
     //
-    //if (verbose){
-    //    end_point = system_clock::now();
-    //    ending = time_point_cast<microseconds>(end_point).time_since_epoch().count();
-    //    Rcout << "C++ Note: df100 " << (ending-start) << " " <<0<< " " <<0<< " " <<-1<< ",Prep_Sides" <<endl;
-    //    gibtime = system_clock::to_time_t(system_clock::now());
-    //    Rcout << "C++ Note: Current Time, " << ctime(&gibtime) << endl;
-    //}
-    //
     if (strata_bool){
         if (verbose){
             Rcout << "C++ Note: riskr checked ";
@@ -493,11 +451,6 @@ void Cox_Side_LL_Calc(const int& reqrdnum, const int& ntime, const IntegerMatrix
     if (single_bool){
         iter_stop=1;
         if (verbose){
-            //end_point = system_clock::now();
-            //ending = time_point_cast<microseconds>(end_point).time_since_epoch().count();
-            //Rcout << "C++ Note: df100 " << (ending-start) << " " <<0<< " " <<0<< " " <<0<< ",Calc" <<endl;//prints the time
-            //gibtime = system_clock::to_time_t(system_clock::now());
-            //Rcout << "C++ Note: Current Time, " << ctime(&gibtime) << endl;
             Rcout << "C++ Note: df101 ";//prints the log-likelihoods
             for (int ij=0;ij<reqrdnum;ij++){
                 Rcout << Ll[ij] << " ";
@@ -511,11 +464,6 @@ void Cox_Side_LL_Calc(const int& reqrdnum, const int& ntime, const IntegerMatrix
         }
     } else {
         if (verbose){
-            //end_point = system_clock::now();
-            //ending = time_point_cast<microseconds>(end_point).time_since_epoch().count();
-            //Rcout << "C++ Note: df100 " << (ending-start) << " " <<0<< " " <<0<< " " <<0<< ",Calc" <<endl;//prints the time
-            //gibtime = system_clock::to_time_t(system_clock::now());
-            //Rcout << "C++ Note: Current Time, " << ctime(&gibtime) << endl;
             Rcout << "C++ Note: df101 ";//prints the log-likelihoods
             for (int ij=0;ij<reqrdnum;ij++){
                 Rcout << Ll[ij] << " ";
@@ -551,16 +499,15 @@ void Cox_Side_LL_Calc(const int& reqrdnum, const int& ntime, const IntegerMatrix
 }
 
 //' Utility function to perform calculation of terms and risks for Poisson Omnibus
+//'
 //' \code{Pois_Term_Risk_Calc} Called to perform repeated term and risk calculations
 //' @inheritParams CPP_template
 //'
 //' @return Updates matrices in place: risk storage matrices
+//' @noRd
+//'
 // [[Rcpp::export]]
 void Pois_Term_Risk_Calc(string modelform, const StringVector& tform, const IntegerVector& Term_n, const int& totalnum, const int& fir, const IntegerVector& dfc, int term_tot, MatrixXd& T0, MatrixXd& Td0, MatrixXd& Tdd0, MatrixXd& Te, MatrixXd& R, MatrixXd& Rd, MatrixXd& Rdd, MatrixXd& Dose, MatrixXd& nonDose, VectorXd beta_0,const  MatrixXd& df0,const double& dint, const double& dslp,  MatrixXd& TTerm,  MatrixXd& nonDose_LIN, MatrixXd& nonDose_PLIN, MatrixXd& nonDose_LOGLIN, MatrixXd& RdR, MatrixXd& RddR, const MatrixXd& s_weights, const int& nthreads, bool debugging, const IntegerVector& KeepConstant, bool verbose, bool strata_bool, bool single_bool, int start, const double gmix_theta, const IntegerVector& gmix_term){
-    time_point<system_clock> end_point;
-    end_point = system_clock::now();
-    auto ending = time_point_cast<microseconds>(end_point).time_since_epoch().count(); //The time duration is tracked
-    auto gibtime = system_clock::to_time_t(system_clock::now());
     int reqrdnum = totalnum - sum(KeepConstant);
     if (single_bool){
 		// Calculates the subterm and term values
@@ -607,15 +554,6 @@ void Pois_Term_Risk_Calc(string modelform, const StringVector& tform, const Inte
 			Rcout << " " << endl;
 		}
 		//
-		//
-		//if (verbose){
-		//	end_point = system_clock::now();
-		//	ending = time_point_cast<microseconds>(end_point).time_since_epoch().count();
-		//	Rcout << "C++ Note: df99," << (ending-start) << ",Prep_Terms" <<endl;
-		//	gibtime = system_clock::to_time_t(system_clock::now());
-		//	Rcout << "C++ Note: Current Time, " << ctime(&gibtime) << endl;
-		//}
-		//
 		// Calculates the risk for each row
 		if (strata_bool){
             Make_Risks_Weighted_Single(modelform, tform, Term_n, totalnum, fir, s_weights, T0, Te, R, Dose, nonDose, TTerm, nonDose_LIN, nonDose_PLIN, nonDose_LOGLIN, nthreads, debugging,KeepConstant,gmix_theta, gmix_term);
@@ -635,11 +573,6 @@ void Pois_Term_Risk_Calc(string modelform, const StringVector& tform, const Inte
 			}
 			Rcout << " " << endl;
 			//
-			//end_point = system_clock::now();
-			//ending = time_point_cast<microseconds>(end_point).time_since_epoch().count();
-			//Rcout << "C++ Note: df100 " << (ending-start) << " " <<0<< " " <<0<< " " <<-1<< ",Prep_R" <<endl;
-			//gibtime = system_clock::to_time_t(system_clock::now());
-			//Rcout << "C++ Note: Current Time, " << ctime(&gibtime) << endl;
 		}
 	} else {
 		//
@@ -698,17 +631,6 @@ void Pois_Term_Risk_Calc(string modelform, const StringVector& tform, const Inte
 			}
 			Rcout << " " << endl;
 		}
-		//
-		//
-		//if (verbose){
-		//	end_point = system_clock::now();
-		//	ending = time_point_cast<microseconds>(end_point).time_since_epoch().count();
-		//	Rcout << "C++ Note: df99," << (ending-start) << ",Prep_Terms" <<endl;
-		//	gibtime = system_clock::to_time_t(system_clock::now());
-		//	Rcout << "C++ Note: Current Time, " << ctime(&gibtime) << endl;
-		//}
-		//
-		//
 		// Calculates the risk for each row
 		if (strata_bool){
             Make_Risks_Weighted(modelform, tform, Term_n, totalnum, fir, s_weights, T0, Td0, Tdd0, Te, R, Rd, Rdd, Dose, nonDose, TTerm, nonDose_LIN, nonDose_PLIN, nonDose_LOGLIN, RdR, RddR, nthreads, debugging,KeepConstant,gmix_theta, gmix_term);
@@ -740,11 +662,6 @@ void Pois_Term_Risk_Calc(string modelform, const StringVector& tform, const Inte
 			}
 			Rcout << " " << endl;
 			//
-			//end_point = system_clock::now();
-			//ending = time_point_cast<microseconds>(end_point).time_since_epoch().count();
-			//Rcout << "C++ Note: df100 " << (ending-start) << " " <<0<< " " <<0<< " " <<-1<< ",Prep_R" <<endl;
-			//gibtime = system_clock::to_time_t(system_clock::now());
-			//Rcout << "C++ Note: Current Time, " << ctime(&gibtime) << endl;
 		}
 	}
 	return;
@@ -752,18 +669,17 @@ void Pois_Term_Risk_Calc(string modelform, const StringVector& tform, const Inte
 
 
 //' Utility function to perform calculation of Log-Likelihood and Deviation for Poisson Omnibus
+//'
 //' \code{Pois_Dev_LL_Calc} Called to perform repeated term and risk calculations
 //' @inheritParams CPP_template
 //' @param dev_temp temporary storage for deviation calculation
 //' @param dev model deviation
 //'
 //' @return Updates matrices in place: risk storage matrices
+//' @noRd
+//'
 // [[Rcpp::export]]
 void Pois_Dev_LL_Calc(const int& reqrdnum, const int& totalnum, const int& fir, MatrixXd& R, MatrixXd& Rd, MatrixXd& Rdd, VectorXd beta_0 , MatrixXd& RdR, MatrixXd& RddR, vector<double>& Ll, vector<double>& Lld, vector<double>& Lldd, const MatrixXd& PyrC, MatrixXd& dev_temp, const int& nthreads, bool debugging, const IntegerVector& KeepConstant, bool verbose, bool single_bool, int start, int iter_stop, double& dev){
-    time_point<system_clock> end_point;
-    end_point = system_clock::now();
-    auto ending = time_point_cast<microseconds>(end_point).time_since_epoch().count(); //The time duration is tracked
-    auto gibtime = system_clock::to_time_t(system_clock::now());
     fill(Ll.begin(), Ll.end(), 0.0);
     if (!single_bool){
         fill(Lld.begin(), Lld.end(), 0.0);
@@ -792,11 +708,6 @@ void Pois_Dev_LL_Calc(const int& reqrdnum, const int& totalnum, const int& fir,
     if (single_bool){
         iter_stop=1;
         if (verbose){
-            //end_point = system_clock::now();
-            //ending = time_point_cast<microseconds>(end_point).time_since_epoch().count();
-            //Rcout << "C++ Note: df100 " << (ending-start) << " " <<0<< " " <<0<< " " <<0<< ",Calc" <<endl;//prints the time
-            //gibtime = system_clock::to_time_t(system_clock::now());
-            //Rcout << "C++ Note: Current Time, " << ctime(&gibtime) << endl;
             Rcout << "C++ Note: df101 ";//prints the log-likelihoods
             for (int ij=0;ij<reqrdnum;ij++){
                 Rcout << Ll[ij] << " ";
@@ -811,11 +722,6 @@ void Pois_Dev_LL_Calc(const int& reqrdnum, const int& totalnum, const int& fir,
         }
     } else {
         if (verbose){
-            //end_point = system_clock::now();
-            //ending = time_point_cast<microseconds>(end_point).time_since_epoch().count();
-            //Rcout << "C++ Note: df100 " << (ending-start) << " " <<0<< " " <<0<< " " <<0<< ",Calc" <<endl;//prints the time
-            //gibtime = system_clock::to_time_t(system_clock::now());
-            //Rcout << "C++ Note: Current Time, " << ctime(&gibtime) << endl;
             Rcout << "C++ Note: df101 ";//prints the log-likelihoods
             for (int ij=0;ij<reqrdnum;ij++){
                 Rcout << Ll[ij] << " ";
